@@ -105,6 +105,10 @@ class LogConfigure:
             handler = self._get_file_handler(".txt")
             formatter = SimpleLogFormatter()
             handler.setFormatter(formatter)
+        elif name == "json-stdout":
+            handler = logging.StreamHandler()
+            formatter = JSONLogFormatter()
+            handler.setFormatter(formatter)
         elif name == "json":
             handler = self._get_file_handler(".json")
             formatter = JSONLogFormatter()
@@ -153,12 +157,13 @@ class LogConfigure:
 
 
 def _init_logger(config: LogConfigure):
-    logger = logging.getLogger("default")
+    loggers = [logging.getLogger(name) for name in logging.root.manager.loggerDict]
 
     if config.cleanup:
-        for h in logger.handlers[:]:
-            logger.removeHandler(h)
-            h.close()
+        for logger in loggers:
+            for h in logger.handlers[:]:
+                logger.removeHandler(h)
+                h.close()
 
     config.directory.mkdir(exist_ok=True)
 
