@@ -104,49 +104,58 @@ class LoggingMiddleware(BaseHTTPMiddleware):
                 media_type=response.media_type,
             )
         duration: int = math.ceil((time.time() - start_time) * 1000)
+        try:
+            request_log_payload = RequestPayload(
+                method=request.method,
+                path=request.url.path,
+                host=f"{server[0]}:{server[1]}",
+                params=dict(request_params),
+                body=request_body,
+            )
+        except Exception as err:
+            print(str(err))
+            request_log_payload = None
 
-        request_log_payload = RequestPayload(
-            method=request.method,
-            path=request.url.path,
-            host=f"{server[0]}:{server[1]}",
-            params=dict(request_params),
-            body=request_body,
-        )
+        try:
+            response_log_payload = ResponsePayload(
+                status=response.status_code,
+                response_time=f"{duration}ms",
+                response_body=response_body.decode(),
+            )
+        except Exception as err:
+            print(str(err))
+            response_log_payload = None
+        try:
+            logger_method = getattr(self._logger, "info" if not exception_object else "error")
 
-        response_log_payload = ResponsePayload(
-            status=response.status_code,
-            response_time=f"{duration}ms",
-            response_body=response_body.decode(),
-        )
+            extra_fields = {
+                "tags": ["API", "REQUEST"],
+                "payload": self._filter_private_data(request_log_payload),
+                "to_mask": True,
+                "progname": self._app_name,
+                "request_id": request_id,
+            }
 
-        logger_method = getattr(self._logger, "info" if not exception_object else "error")
+            logger_method(
+                f"REQUEST {request.method} {request.url.path}",
+                extra=extra_fields,
+                exc_info=exception_object,
+            )
 
-        extra_fields = {
-            "tags": ["API", "REQUEST"],
-            "payload": self._filter_private_data(request_log_payload),
-            "to_mask": True,
-            "progname": self._app_name,
-            "request_id": request_id,
-        }
+            extra_fields["tags"] = ["API", "RESPONSE"]
+            extra_fields["payload"] = self._filter_private_data(response_log_payload)
 
-        logger_method(
-            f"REQUEST {request.method} {request.url.path}",
-            extra=extra_fields,
-            exc_info=exception_object,
-        )
-
-        extra_fields["tags"] = ["API", "RESPONSE"]
-        extra_fields["payload"] = self._filter_private_data(response_log_payload)
-
-        logger_method(
-            f"RESPONSE {response.status_code} {request.url.path}",
-            extra=extra_fields,
-            exc_info=exception_object,
-        )
+            logger_method(
+                f"RESPONSE {response.status_code} {request.url.path}",
+                extra=extra_fields,
+                exc_info=exception_object,
+            )
+        except Exception as err:
+            print(str(err))
 
         return response
 
-    def _filter_private_data(self, payload: dict):
+    def _filter_private_data(self, payload: dict | None):
         _filtered_fields = LogConfigure().get_exclude_fields()
         _marker_filtered = "[filtered]"
         if "params" in payload.keys():
